==> console-container-v2.3.0-127.tar.gz: package/DownloadButton/DownloadButton.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _typeof = require("@babel/runtime/helpers/typeof");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));

var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));

var _classCallCheck2 = _interopRequireDefault(require("@babel/runtime/helpers/classCallCheck"));

var _createClass2 = _interopRequireDefault(require("@babel/runtime/helpers/createClass"));

var _assertThisInitialized2 = _interopRequireDefault(require("@babel/runtime/helpers/assertThisInitialized"));

var _inherits2 = _interopRequireDefault(require("@babel/runtime/helpers/inherits"));

var _possibleConstructorReturn2 = _interopRequireDefault(require("@babel/runtime/helpers/possibleConstructorReturn"));

var _getPrototypeOf2 = _interopRequireDefault(require("@babel/runtime/helpers/getPrototypeOf"));

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _Dropdown = require("@patternfly/react-core/dist/js/components/Dropdown/Dropdown.js");

var _DropdownItem = require("@patternfly/react-core/dist/js/components/Dropdown/DropdownItem.js");

var _DropdownToggle = require("@patternfly/react-core/dist/js/components/Dropdown/DropdownToggle.js");

var _Tooltip = require("@patternfly/react-core/dist/js/components/Tooltip/Tooltip.js");

var _react = _interopRequireWildcard(require("react"));

var _exportIcon = _interopRequireDefault(require("@patternfly/react-icons/dist/js/icons/export-icon"));

var _propTypes = _interopRequireDefault(require("prop-types"));

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = (0, _getPrototypeOf2["default"])(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = (0, _getPrototypeOf2["default"])(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return (0, _possibleConstructorReturn2["default"])(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

var DownloadButton = /*#__PURE__*/function (_Component) {
  (0, _inherits2["default"])(DownloadButton, _Component);

  var _super = _createSuper(DownloadButton);

  function DownloadButton() {
    var _this;

    (0, _classCallCheck2["default"])(this, DownloadButton);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _super.call.apply(_super, [this].concat(args));
    (0, _defineProperty2["default"])((0, _assertThisInitialized2["default"])(_this), "state", {
      isOpen: false
    });
    (0, _defineProperty2["default"])((0, _assertThisInitialized2["default"])(_this), "onToggle", function (isOpen) {
      _this.setState({
        isOpen: isOpen
      });
    });
    (0, _defineProperty2["default"])((0, _assertThisInitialized2["default"])(_this), "onSelect", function () {
      _this.setState({
        isOpen: !_this.state.isOpen
      });
    });
    (0, _defineProperty2["default"])((0, _assertThisInitialized2["default"])(_this), "conditionallyTooltip", function (children) {
      var tooltipText = _this.props.tooltipText;
      return /*#__PURE__*/_react["default"].createElement(_react["default"].Fragment, null, tooltipText ? /*#__PURE__*/_react["default"].createElement(_Tooltip.Tooltip, {
        content: tooltipText
      }, children) : children);
    });
    return _this;
  }

  (0, _createClass2["default"])(DownloadButton, [{
    key: "render",
    value: function render() {
      var isOpen = this.state.isOpen;
      var _this$props = this.props,
          extraItems = _this$props.extraItems,
          onSelect = _this$props.onSelect,
          isDisabled = _this$props.isDisabled,
          tooltipText = _this$props.tooltipText,
          props = (0, _objectWithoutProperties2["default"])(_this$props, ["extraItems", "onSelect", "isDisabled", "tooltipText"]);
      return /*#__PURE__*/_react["default"].createElement(_react["default"].Fragment, null, this.conditionallyTooltip( /*#__PURE__*/_react["default"].createElement(_Dropdown.Dropdown, (0, _extends2["default"])({}, props, {
        isPlain: true,
        onSelect: this.onSelect,
        toggle: /*#__PURE__*/_react["default"].createElement(_DropdownToggle.DropdownToggle, {
          toggleIndicator: null,
          onToggle: this.onToggle,
          isDisabled: isDisabled,
          ouiaId: "toggle"
        }, /*#__PURE__*/_react["default"].createElement(_exportIcon["default"], {
          size: "sm"
        })),
        isOpen: isOpen,
        dropdownItems: [/*#__PURE__*/_react["default"].createElement(_DropdownItem.DropdownItem, {
          key: "download-csv",
          ouiaId: "download-csv",
          component: "button",
          onClick: function onClick(event) {
            return onSelect(event, 'csv');
          },
          isDisabled: isDisabled
        }, "Export to CSV"), /*#__PURE__*/_react["default"].createElement(_DropdownItem.DropdownItem, {
          key: "download-json",
          ouiaId: "download-json",
          component: "button",
          onClick: function onClick(event) {
            return onSelect(event, 'json');
          },
          isDisabled: isDisabled
        }, "Export to JSON")].concat((0, _toConsumableArray2["default"])(extraItems))
      }))));
    }
  }]);
  return DownloadButton;
}(_react.Component);

DownloadButton.propTypes = {
  extraItems: _propTypes["default"].arrayOf(_propTypes["default"].node),
  tooltipText: _propTypes["default"].node,
  onSelect: _propTypes["default"].func,
  isDisabled: _propTypes["default"].bool
};
DownloadButton.defaultProps = {
  extraItems: [],
  onSelect: function onSelect() {
    return undefined;
  }
};
var _default = DownloadButton;
exports["default"] = _default;

==> console-container-v2.3.5-1.tar.gz: package/DownloadButton/DownloadButton.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _typeof = require("@babel/runtime/helpers/typeof");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));

var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));

var _classCallCheck2 = _interopRequireDefault(require("@babel/runtime/helpers/classCallCheck"));

var _createClass2 = _interopRequireDefault(require("@babel/runtime/helpers/createClass"));

var _assertThisInitialized2 = _interopRequireDefault(require("@babel/runtime/helpers/assertThisInitialized"));

var _inherits2 = _interopRequireDefault(require("@babel/runtime/helpers/inherits"));

var _possibleConstructorReturn2 = _interopRequireDefault(require("@babel/runtime/helpers/possibleConstructorReturn"));

var _getPrototypeOf2 = _interopRequireDefault(require("@babel/runtime/helpers/getPrototypeOf"));

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _Dropdown = require("@patternfly/react-core/dist/js/components/Dropdown/Dropdown.js");

var _DropdownItem = require("@patternfly/react-core/dist/js/components/Dropdown/DropdownItem.js");

var _DropdownToggle = require("@patternfly/react-core/dist/js/components/Dropdown/DropdownToggle.js");

var _Tooltip = require("@patternfly/react-core/dist/js/components/Tooltip/Tooltip.js");

var _react = _interopRequireWildcard(require("react"));

var _exportIcon = _interopRequireDefault(require("@patternfly/react-icons/dist/js/icons/export-icon"));

var _propTypes = _interopRequireDefault(require("prop-types"));

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = (0, _getPrototypeOf2["default"])(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = (0, _getPrototypeOf2["default"])(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return (0, _possibleConstructorReturn2["default"])(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

var DownloadButton = /*#__PURE__*/function (_Component) {
  (0, _inherits2["default"])(DownloadButton, _Component);

  var _super = _createSuper(DownloadButton);

  function DownloadButton() {
    var _this;

    (0, _classCallCheck2["default"])(this, DownloadButton);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _super.call.apply(_super, [this].concat(args));
    (0, _defineProperty2["default"])((0, _assertThisInitialized2["default"])(_this), "state", {
      isOpen: false
    });
    (0, _defineProperty2["default"])((0, _assertThisInitialized2["default"])(_this), "onToggle", function (isOpen) {
      _this.setState({
        isOpen: isOpen
      });
    });
    (0, _defineProperty2["default"])((0, _assertThisInitialized2["default"])(_this), "onSelect", function () {
      _this.setState({
        isOpen: !_this.state.isOpen
      });
    });
    (0, _defineProperty2["default"])((0, _assertThisInitialized2["default"])(_this), "conditionallyTooltip", function (children) {
      var tooltipText = _this.props.tooltipText;
      return /*#__PURE__*/_react["default"].createElement(_react["default"].Fragment, null, tooltipText ? /*#__PURE__*/_react["default"].createElement(_Tooltip.Tooltip, {
        content: tooltipText
      }, children) : children);
    });
    return _this;
  }

  (0, _createClass2["default"])(DownloadButton, [{
    key: "render",
    value: function render() {
      var isOpen = this.state.isOpen;
      var _this$props = this.props,
          extraItems = _this$props.extraItems,
          onSelect = _this$props.onSelect,
          isDisabled = _this$props.isDisabled,
          tooltipText = _this$props.tooltipText,
          props = (0, _objectWithoutProperties2["default"])(_this$props, ["extraItems", "onSelect", "isDisabled", "tooltipText"]);
      return /*#__PURE__*/_react["default"].createElement(_react["default"].Fragment, null, this.conditionallyTooltip( /*#__PURE__*/_react["default"].createElement(_Dropdown.Dropdown, (0, _extends2["default"])({}, props, {
        isPlain: true,
        onSelect: this.onSelect,
        toggle: /*#__PURE__*/_react["default"].createElement(_DropdownToggle.DropdownToggle, {
          toggleIndicator: null,
          onToggle: this.onToggle,
          isDisabled: isDisabled,
          ouiaId: "Export"
        }, /*#__PURE__*/_react["default"].createElement(_exportIcon["default"], {
          size: "sm"
        })),
        isOpen: isOpen,
        ouiaId: "Export",
        dropdownItems: [/*#__PURE__*/_react["default"].createElement(_DropdownItem.DropdownItem, {
          key: "download-csv",
          ouiaId: "DownloadCSV",
          component: "button",
          onClick: function onClick(event) {
            return onSelect(event, 'csv');
          },
          isDisabled: isDisabled
        }, "Export to CSV"), /*#__PURE__*/_react["default"].createElement(_DropdownItem.DropdownItem, {
          key: "download-json",
          ouiaId: "DownloadJSON",
          component: "button",
          onClick: function onClick(event) {
            return onSelect(event, 'json');
          },
          isDisabled: isDisabled
        }, "Export to JSON")].concat((0, _toConsumableArray2["default"])(extraItems))
      }))));
    }
  }]);
  return DownloadButton;
}(_react.Component);

DownloadButton.propTypes = {
  extraItems: _propTypes["default"].arrayOf(_propTypes["default"].node),
  tooltipText: _propTypes["default"].node,
  onSelect: _propTypes["default"].func,
  isDisabled: _propTypes["default"].bool
};
DownloadButton.defaultProps = {
  extraItems: [],
  onSelect: function onSelect() {
    return undefined;
  }
};
var _default = DownloadButton;
exports["default"] = _default;
